@@ -2,7 +2,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 
     SPDX-FileCopyrightText: 2003 Brian Thomas <thomas@mail630.gsfc.nasa.gov>
-    SPDX-FileCopyrightText: 2004-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2004-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 #ifndef CPPCODEGENERATOR_H
@@ -48,7 +48,7 @@ public:
     virtual void writeCodeToFile();
     virtual void writeCodeToFile(UMLClassifierList &list);
 
-    QStringList defaultDatatypes();
+    QStringList defaultDatatypes() const;
 
     virtual void saveToXMI1(QXmlStreamWriter& writer);
 
