@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *  copyright (C) 2006-2014                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef OBJECT_FACTORY__H
 #define OBJECT_FACTORY__H
@@ -30,7 +25,8 @@ UMLObject* createUMLObject(UMLObject::ObjectType type,
 
 UMLObject* createNewUMLObject(UMLObject::ObjectType type,
                               const QString &n,
-                              UMLPackage *parentPkg);
+                              UMLPackage *parentPkg,
+                              bool undoable = true);
 
 UMLClassifierListItem* createChildObject(UMLClassifier *parent,
                                          UMLObject::ObjectType type,
