@@ -1,6 +1,6 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
-    SPDX-FileCopyrightText: 2003-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+    SPDX-FileCopyrightText: 2003-2021 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
 */
 
 // own header
@@ -46,7 +46,8 @@ UMLTemplate::~UMLTemplate()
 {
 }
 
-QString UMLTemplate::toString(Uml::SignatureType::Enum sig, bool withStereotype)
+QString UMLTemplate::toString(Uml::SignatureType::Enum sig,
+                              bool withStereotype) const
 {
     Q_UNUSED(sig);
     QString s;
